function [profiles]...
              =profile1d_lp(variance_factor,PEs,num_coils,center, max_sensitivity,backgroundphase_freq) 
%Profile1d.m: generate sensitivity profile with phase modulation, complex 
%  output: true profiles
%  backgroundphase_freq: in term of FOV, if ==1, 2*pi variation in the
%  whole FOV
%Copyright: JIM X. JI
%TAMU
%----------------------------------------------
% Copyright (C) 2005 Jim Ji, Texas A&M University.
% All Rights Reserved.

% References:


% Version of 4-June-2005.

% Log:
% Created  2003 Jim Ji	Source code
% Updated
%-----------------------------------------------------
%-------------------------------------------------------------
%input=number of coils ->num_coils
%image field of vies->FOV
%variance/localization of the coil sensitivity-> sigma
%coil centers ->center
%maximumsensitivity possible ->max_sensitivity;
%background phase -> background_phase
%-------------------------------------------------------------
%output=ideal coil profiles->profiles
%-------------------------------------------------------------



FOV=PEs;
x=0:(FOV-1);
profiles = zeros(FOV,num_coils);
for coil = 1:num_coils
	a=normpdf(x,center(coil),variance_factor(coil))';
    profiles(:,coil)=a.*max_sensitivity/max(a);

    %phase factor; assume the 3*variance_factor covers a range of phase (two circles)
    %   0->pi  (-pi)->0->pi  (-pi)-> 0 
 
     if nargin==6
        freq = 4*pi/(3*variance_factor(coil));
        freq = 2*pi*backgroundphase_freq;
        phase = exp(j*freq*(x'-center(coil)));
        profiles(:,coil)=a.*max_sensitivity/max(a).*phase;
     end%, April 25, 2005
end
%backgroundphase specifically added for SMASH code. Firstly the harmonics
%were not getting generated properly with complex profiles. Now they do.
%Aug. 30, 2004

return



