function [rough_map,regularization_image]...
    = sensitivity_walsh(full_kspace_data,center_data,num_coils,center_lines,center_locs,PEs,FEs,subsampling_factor,sampling_location,data_type)
%------------------------------------------
%function sensitivity = sensitivity_walsh(refimg, width)
% refimg:size (Nx,Ny,Ncoils)
% width, W*W averaging range for correlation matrix, see walsh's paper on
% adaptive phased-array imaginary reconstruction
%
% output: Nx,Ny, Ncoils, sensitivity map
%
% Jim Ji, Texas A&M University, 2005, All rights reserved
% jimji@tamu.edu
%----------------------------------------------
% Copyright (C) 2005 Jim Ji, Texas A&M University.
% All Rights Reserved.

% References:  Adaptive Reconstructin of MR Phased Array Imagery
%              D.O. Walsh,A. Gmitro and M. Marcellin 
%              Magentic Resonance in Medicine,vol.43(5), pp.~680-692, 2000

% Version of 4-June-2005.

% Log:
% Created  2005 Jim Ji, Modified Swati Rane	Source code
% Updated
%-----------------------------------------------------
Ro=FEs;
C=PEs;
window_col=hamming(center_lines);
hamm_window=repmat(window_col,[1 Ro]);
hamm_window_full=zeros(Ro,C);
hamm_window_full(:,C/2-center_lines/2:C/2+center_lines/2-1)=transpose(hamm_window); %zeroed the figh frequency
if(data_type==4)%reduced kpace data available unlike the others so need to find where are the central extra lines
    for(i=1:num_coils)
       k_sub_coil(:,:,i)=zeros(Ro,C);
       k_sub_coil(:,center_locs,i)=center_data(:,:,i);
       k_coil_full(:,:,i)=k_sub_coil(:,:,i).*hamm_window_full;
       coil_full(:,:,i)=ifftshift(ifft2(ifftshift(k_coil_full(:,:,i))));
       %figure, imagesc(abs(coil_full(:,:,i)));
       %sos_data(:,:,i)=center_data(:,:,i);
       % changed January 21, 2005
     end      
 else
    sampl_in=round(center_lines/subsampling_factor);
    collect_lines=round(union([C/2-center_lines/2-sampl_in:C/2+center_lines/2+sampl_in-1],sampling_location));
    %collect_lines=union([C/2-center_lines:C/2+center_lines-1],sampling_loc
    %ation); Nov. 11
    for(i=1:num_coils)
        k_sub_coil(:,:,i)=zeros(Ro,C);
        k_sub_coil(:,collect_lines,i)=full_kspace_data(:,collect_lines,i);
        %sos_data(:,:,i)=k_sub_coil(:,:,i);
        k_coil_full(:,:,i)=k_sub_coil(:,:,i).*hamm_window_full;
        refimg(:,:,i)=ifftshift(ifft2(ifftshift(k_coil_full(:,:,i))));
        %figure, imagesc(abs(coil_full(:,:,i)));
        %sos_data(:,:,i)=full_kspace_data(:,C/2-center_lines/2:C/2+center_lines
        %/2-1,i); Nov. 12
    end
end

% for(i=1:num_coils)
%     refimg(:,:,i)=ifftshift(ifft2(ifftshift(k_coil_full(:,:,i))));
% end

Rcorr=zeros(Ro,C,num_coils,num_coils); 
for i=1:Ro
    i;
    for j=1:C
            f = refimg(i,j,:);
            f=f(:); 
            Rcorr(i,j,:,:) = f*f';
    end
end
width=3;% Jan 27, 2005;
%smoothing
win=ones(width,width)/(width*width);

for m=1:num_coils;
    for n=1:num_coils;
        Rcorr(:,:,m,n)=filter2(win,Rcorr(:,:,m,n),'same');
    end
end

%eigen decomposition
rough_map=zeros(Ro,C,num_coils);
for i=1:Ro
    i;
    for j=1:C
        D=squeeze(Rcorr(i,j,:,:));
        [v,d]=eig(D);
        w=v(:,num_coils);%/sqrt(d(num_coils,num_coils)); %Not necessary to normalize with ||f||_2

        %sensitivity
        rough_map(i,j,:)=reshape(w,[1 1 num_coils]);
    end
end
regularization_image=sqrt(sum(refimg.^2,3)/num_coils);
return