function [recon] = pils_gauss(rough_map,gauss_fit,reduced_kspace_data,subsampling_factor,lin_flag)
%---------------------------------------------------
% Copyright (C) 2005 Jim Ji, Texas A&M University.
% All Rights Reserved.

% References: Partially Parallel Imaging with Localised Sensitivities (PILS)
%                    M.A. Griswold
%                    Magnetic Resonance in Medicine, 44::602-609 (2000)

% Version of 4-June-2005.

% Log:
% Created  2003 Jim Ji	Source code, Modified Jong Bum Son, Swati Rane
% Updated
%-----------------------------------------------------
%----------------------------------
%input=estimated maps->rough_maps
%reduced dataset->reduced_kspace_data
%rough estimate of the centers->center
%subsampling factor
%-------------------------------------
%output=reconstructed image
%------------------------------------
%PILS RECONSTRUCTED IS DONE. IF THE ARRAY IS NON-LINEAR, THEN THE CENTERS
%ARE ESTIMATED USING GAUSSIAN FITTING OTHERWISE,THE CENTERS ARE DIRECTLY
%APPROXIMATED.
%-----------------------------------
[Ro C num_coils]=size(rough_map);

if(lin_flag==1)
    for(i=1:num_coils)
        [maxi index]=max(gauss_fit(Ro/2,:,i));
        center(i)=index;
     end
     tk=0;
else
    tk=0;
        for(i=1:num_coils)
            temp_max=max(gauss_fit(:,:,i));
            [maxi center(i)]=max(temp_max(:));
        end

end

negative_flag = 0;
if(lin_flag==1)
    if center(num_coils)<center(1) 
      negative_flag = 1; %applicable only to linear
    end
end
%----------added October 3,4 -----------------
overlapped_img = zeros(size(reduced_kspace_data));
[FEs,Npe_seg,Ncoils] = size(overlapped_img);
%PEs = max(center)-min(center) + Npe_seg;
PEs = subsampling_factor*Npe_seg;

% generate the overlapped_img: (FEs,PEs/subsampling_factor,Ncoils) 
% index as [-N/2:(N/2-1)].  Centered, unshifted 
coil_image = zeros(FEs,PEs,Ncoils);
ind=0;
for coil=1+tk:Ncoils-tk %tk added October 4
    ktmp = reduced_kspace_data(:,:,coil);
    ind=ind+1;%added October 4
    mod = exp(-sqrt(-1)*2*pi/Npe_seg*(center(ind)-(PEs/2+1))*[-Npe_seg/2:(Npe_seg/2-1)]);
    ktmp = ktmp.*repmat([mod(:)]',[FEs,1]);
    overlapped_img(:,:,coil)=ifftshift(ifft2(ifftshift(ktmp)));
    if(lin_flag==0)
        if(abs(center(coil)- (1-negative_flag)*center(1) - negative_flag*center(Ncoils))+Npe_seg>PEs)
            shift=abs(center(coil)- (1-negative_flag)*center(1) - negative_flag*center(Ncoils))+Npe_seg-PEs;
        else 
            shift=0;%shift Nov. 13
        end
    else
        shift=0;
    end
    coil_image(:,[1:Npe_seg] + abs(center(coil)- (1-negative_flag)*center(1) - negative_flag*center(Ncoils))-shift,coil) = overlapped_img(:,:,coil);

%     coil_image(:,[1:Npe_seg]+abs(center(ind)-center(1)),coil) = overlapped_img(:,:,coil); %Nov. 14
%     %coil_image(:,:,i)=overlapped_img(:,:,coil).*coil_FOV(:,:,coil);
 end

% sum of square
recon=sqrt(sum([abs(coil_image)].^2,3));%/Ncoils);
return
