function [recon] = sense(rough_map, reduced_kspace_data)
%input= coil_maps, reduced kspace data 
%output SENSE reconstructed image
%--------------------------------------------------------
% function [recon] = sense(sensitivity, reduced_kspace_data)
% The reductin is done along the second dimension.
% sensitivity: (FEs,PEs,Ncoils) sensitivity map 
% reduced_kspace_data: (FEs,PEs/R,Ncoils)
% solution: (FEs,PEs) reconstruced image;
%
% Jim Ji, 2002
% University of Illinois at Urbanan-Champaign
%----------------------------------------------------------
%----------------------------------------------
% Copyright (C) 2005 Jim Ji, Texas A&M University.
% All Rights Reserved.

% References:Sensitivity Encoding for fast MRI Scans (SENSE)
%                   K. Pruessmann, M. Weiger, P.Boesieger
%                   Magnetic Resonance in Medicine, 42:952-962 (1999)

% Version of 4-June-2005.

% Log:
% Created  2002 Jim Ji	Source code
% Updated
%-----------------------------------------------------
overlapped_img = zeros(size(reduced_kspace_data));
[FEs,Npe_seg,Ncoils] = size(overlapped_img);
PEs = size(rough_map,2);
Rr = round(PEs/Npe_seg); %if R-round(R) ~=0; display('Reduction factor must be integer!'); return; end;

% generate the overlapped_img: (FEs,PEs/R,Ncoils) 
% index as [-N/2:(N/2-1)].  Centered, unshifted 
for coil=1:Ncoils
 overlapped_img(:,:,coil)=ifftshift(ifft2(ifftshift(reduced_kspace_data(:,:,coil))));
end

%shift the overlapped image
%fftshift the overlapped_image so it corresponds to the first I(0:(N/2-1)) segment
%For even reduction factor only.  For odd reduction factor, the central portion does not need to be shifted.

if mod(Rr,2)==0
    tmp_img  = overlapped_img;
	overlapped_img(:,1:(Npe_seg/2),:) = tmp_img(:,(Npe_seg/2+1):Npe_seg,:);
	overlapped_img(:,(Npe_seg/2+1):Npe_seg,:) = tmp_img(:,1:(Npe_seg/2),:);
end
recon=zeros(FEs,PEs);
for pe=1:Npe_seg
   pe;
   for i=1:FEs
       if((pe+Npe_seg*(Rr-1))>PEs)
           delt=(pe+Npe_seg*(Rr-1))-PEs;
       else
           delt=0;
       end
   	  s1=squeeze(rough_map(i,pe:Npe_seg:(pe-delt+Npe_seg*(Rr-1)),:));
      s=transpose(s1);
      I_mat=squeeze(overlapped_img(i,pe,:));
      recon(i,pe:Npe_seg:(pe-delt+Npe_seg*(Rr-1))) = transpose((inv(s'*s)*s'*I_mat));
      tmp = pinv(s'*s).*(s'*s); tmp = sqrt(abs(diag(tmp)));
      gmap(i,pe:Npe_seg:(pe+Npe_seg*(Rr-1)))= tmp';
  
      %condmap(i,pe:Npe_seg:(pe+Npe_seg*(Rr-1)))= cond(s);
  end 
end
imagesc(abs(1./gmap));colormap('gray');
return