function [Pcos, Psin,Nharm,sinrec,cosrec]=smash_fit_harmonic(fitted_profiles,subsampling_factor,fit_img,per)
%----------------------------------------------
% Copyright (C) 2005 Jim Ji, Texas A&M University.
% All Rights Reserved.

% References:Simultaneous Acquisition of Spatial Harmonics using radio-frequency                    coil Array, D. SoDickson
%                   Magnetic Resonance in Medicine,38:591-563 (1997)

% Version of 4-June-2005.

% Log:
% Created  2003 Jim Ji, Modified 2004 Swati Rane	Source code
% Updated
%-----------------------------------------------------
%input= regenerated profiles
%subsampling factor
%flag for tight harmonic fitting ->fit_img
%-------------------------------------------------------
%output= sin and cos coefficients for harmonic fitting->Pcos,Psin
%number of harmonics -> Nharm
%actual reconstructed harmonics (not required anywhere-check)->cosrec
%sinrec;
%--------------------------------------------------------------------------

%fitted_profiles: the sensitivity map after low-order polynomial fitting
[PEs,Nc]=size(fitted_profiles);

Nharm= ceil((Sampling.subsampling_factor+1)/2);
%-added on September 17, 2004 for better harmonic fitting with
%-the calculated sensitivity maps---%
if(fit_img==1)
    wid=(per)*PEs/200;
    start_fov=round(PEs/2-wid-2);%input('Start: ');
    end_fov=round(PEs/2+wid+2);%input('Stop: ');
else
    start_fov=1;
    end_fov=PEs;
end
    
truncated_profiles=fitted_profiles(start_fov:end_fov,:);

n=[(-PEs/2):(PEs/2-1)]';
deltak=1/PEs*2*pi;
Pcos=zeros(Nc,Nharm);
Psin=Pcos;
cosrec=zeros(PEs,Nharm);
sinrec=cosrec;
%finding the coefficients to generate the harmonics
for i=1:Nharm
   cosint=cos(n*deltak*(i-1));
   pv=pinv(truncated_profiles);
   %Pcos(:,i)=pv*cosint;
   %September 17, 2007
   Pcos(:,i)=pv*cosint(start_fov:end_fov);
   sinint=sin(n*deltak*(i-1));
   %Psin(:,i)=pv*sinint;
   %spetember 17, 2004
   Psin(:,i)=pv*sinint(start_fov:end_fov);
   
   cosrec(:,i)=(fitted_profiles)*Pcos(:,i);
   sinrec(:,i)=(fitted_profiles)*Psin(:,i);
  
end   

return