function [reduced_kspace_data, Sampling] = sample_kd(full_kspace_data,Sampling)
%----------------------------------------------
% Copyright (C) 2005 Jim Ji, Texas A&M University.
% All Rights Reserved.

% References:


% Version of 4-June-2005.

% Log:
% Modified 2004 from kspacedata_sim.m Swati Rane	Source code
% Updated
%-----------------------------------------------------
%------------------------------------------
%input=full kspace data ->full_kspace_data
%subsampling_factor ->subsampling_factor;
%-------------------------------------------
%output=reduced/subsampled kspace data
%sampling locations along the phase encoding direction->sampling_location
%-------------------------------------------
% simulate subsampled k-space data from each coil; reduction in the second
% direction
% sensitivity(PEs,FEs,Num_coils)
% image(PEs, FEs) is the whole image without sensitivity modulation
% subsampling_factor: R, subsampling factor
% SNR: the signal-to-noise ratio, in dB, of the k-space data;
%---------------------------------------------

[Ro,C, num_coils]=size(full_kspace_data);
%----------------------------------------------
% the sampling location is the subsampling location; need to take care of
% the even/odd reduction factor; make sure that the central k-space
% (C/2+1) is sampled and the subsampled phase-encodings is an even number.
%----------------------------------------------
tmp1 = (C/2+1-Sampling.subsampling_factor):(-Sampling.subsampling_factor):1;
tmp2 = (C/2+1):Sampling.subsampling_factor:C;
Sampling.sampling_location = [flipud(tmp1(:)); tmp2(:)]; 
if length(tmp1)>length(tmp2)
    Sampling.sampling_location=Sampling.sampling_location(2:length(Sampling.sampling_location));
    else if length(tmp1)<length(tmp2)
        Sampling.sampling_location=Sampling.sampling_location(1:length(Sampling.sampling_location)-1);
    end
end

for coil = 1:num_coils
    reduced_kspace_data(:,:,coil) = full_kspace_data(:,Sampling.sampling_location,coil);
end

return