function [recon]=smash(measured_subsamp_kdata,reg_profiles,Sampling,Flags,Misc);
%----------------------------------------
%input= reduced_kspace_data, 
%regenerated coil maps ->rough_maps
%reduction factor ->subsampling_factor
%sampling_location, flag for strict harmonic fitting->fit_img
%-----------------------------------------
%output= SMASH reconstructed image
%-----------------------------------------
%SMASH RECONSTRUCTION IS DONE: SMOOTH SINUSOIDS ARE GENERATED USING
%smash_fit_harmonics.m. THE DATA HASE TO BE ARRANGED CAREFULLY AFTER IT IS
%SHIFTED FOR SMASH RECONSTRUCTION. THE ARRANEGMENT PROCDURE IS INDICATED
%IN THE COMMENTS BELOW
%-----------------------------------------
%----------------------------------------------
% Copyright (C) 2005 Jim Ji, Texas A&M University.
% All Rights Reserved.

% References:Simultaneous Acquisition of Spatial Harmonics using radio-frequency                    coil Array, D. SoDickson
%                   Magnetic Resonance in Medicine,38:591-563 (1997)

% Version of 4-June-2005.

% Log:
% Created  2004 Jim Ji and Swati Rane	Source code
% Updated
%-----------------------------------------------------
[Npe,Nc]=size(reg_profiles);
[Nfe,Np,Nc]=size(measured_subsamp_kdata);

%fit the harmonics
[Pcos, Psin,Nharm,sinrec,cosrec]=smash_fit_harmonic(reg_profiles,Sampling,Flags,Misc);
kdata=zeros(Nfe,Npe);
tempdata=reshape(measured_subsamp_kdata,Nfe*Np,Nc);

for kshift = [- floor(Sampling.subsampling_factor/2) : floor(Sampling.subsampling_factor/2)]
      harmonic_index=abs(kshift)+1;
      harmonic_sign=sign(kshift);
      coef_sin=Psin(:,harmonic_index);
      coef_cos=Pcos(:,harmonic_index);
      dataset=tempdata*(coef_cos - harmonic_sign*sqrt(-1)*coef_sin);
      dataset=reshape(dataset,Nfe,Np);
      %to arrange the harmonics correctly depending on the sampling location
      %e.g for factor of 4
      %sampling location: 1  5   9   13  ...
      %kspace columns:     1    2   3       4   5   6   7       8   9   10
      %harmonics  opsition:0    1   2,-2   -1   0   1   2,-2    -1  0   1  ...
      %here 2 and -2 harmonic are the same , so averaging is done
      %for a factor of 3
      %sampling location:  2   5   8   11  14
      %kspace columns:     1   2   3   4   5   6   7   8   9 ...
      %harmonics position: -1  0   1  -1   0   1  -1   0   1 ...
      %for all even factors, averaging was required.
      %sampling locationare chose sucht that the center of kspace is always
      %collected     
      if kshift==0
        kdata(:,Sampling.sampling_location )=dataset;
      elseif kshift>0
        kdata(:,Sampling.sampling_location + abs(kshift))=dataset;
      elseif kshift<0
        if rem(Sampling.subsampling_factor,2)==1 % odd
            if(Sampling.sampling_location(1)-abs(kshift)<=0)
                factor=Sampling.subsampling_factor;
            else
                factor=0;
            end
            if sum(kdata(:,Sampling.sampling_location+factor  - abs(kshift) )~=0 ) ~=0
                kdata(:,Sampling.sampling_location+factor  - abs(kshift) ) = (kdata(:,Sampling.sampling_location+factor  - abs(kshift) ) + dataset)/2;
            else
                kdata(:,Sampling.sampling_location+factor  - abs(kshift) ) = dataset;
            end
        else %even
            dataset = circshift(dataset, [0 kshift]);
            if sum(kdata(:,Sampling.sampling_location + Sampling.subsampling_factor - abs(kshift) ) ~=0) ~=0
                kdata(:,Sampling.sampling_location + Sampling.subsampling_factor - abs(kshift) ) = (kdata(:,Sampling.sampling_location + Sampling.subsampling_factor - abs(kshift) ) + dataset)/2;        
            else                
                kdata(:,Sampling.sampling_location + Sampling.subsampling_factor - abs(kshift) ) = dataset;
            end
            
        end
    end
end
 
[recon]=idft(kdata,Nfe,Npe);

return